==> open-cluster-management-operator-model-6.3.0-sources.jar: io/fabric8/openclustermanagement/api/model/multiclusterhub/operator/v1/HiveConfigSpecFluent.java <==
package io.fabric8.openclustermanagement.api.model.multiclusterhub.operator.v1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import java.util.function.Predicate;
import java.lang.Deprecated;
import java.util.Iterator;
import java.util.List;
import java.lang.Boolean;
import io.fabric8.kubernetes.api.model.LocalObjectReferenceFluent;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.model.LocalObjectReferenceBuilder;
import java.lang.Integer;
import io.fabric8.kubernetes.api.model.LocalObjectReference;
import java.util.Collection;

 /**
  * Generated
  */
public interface HiveConfigSpecFluent<A extends HiveConfigSpecFluent<A>> extends Fluent<A>{
  public A addToAdditionalCertificateAuthorities(Integer index,LocalObjectReference item);
  public A setToAdditionalCertificateAuthorities(Integer index,LocalObjectReference item);
  public A addToAdditionalCertificateAuthorities(io.fabric8.kubernetes.api.model.LocalObjectReference... items);
  public A addAllToAdditionalCertificateAuthorities(Collection<LocalObjectReference> items);
  public A removeFromAdditionalCertificateAuthorities(io.fabric8.kubernetes.api.model.LocalObjectReference... items);
  public A removeAllFromAdditionalCertificateAuthorities(Collection<LocalObjectReference> items);
  public A removeMatchingFromAdditionalCertificateAuthorities(Predicate<LocalObjectReferenceBuilder> predicate);
  
  /**
   * This method has been deprecated, please use method buildAdditionalCertificateAuthorities instead.
   * @return The buildable object.
   */
  @Deprecated
  public List<LocalObjectReference> getAdditionalCertificateAuthorities();
  public List<LocalObjectReference> buildAdditionalCertificateAuthorities();
  public LocalObjectReference buildAdditionalCertificateAuthority(Integer index);
  public LocalObjectReference buildFirstAdditionalCertificateAuthority();
  public LocalObjectReference buildLastAdditionalCertificateAuthority();
  public LocalObjectReference buildMatchingAdditionalCertificateAuthority(Predicate<LocalObjectReferenceBuilder> predicate);
  public Boolean hasMatchingAdditionalCertificateAuthority(Predicate<LocalObjectReferenceBuilder> predicate);
  public A withAdditionalCertificateAuthorities(List<LocalObjectReference> additionalCertificateAuthorities);
  public A withAdditionalCertificateAuthorities(io.fabric8.kubernetes.api.model.LocalObjectReference... additionalCertificateAuthorities);
  public Boolean hasAdditionalCertificateAuthorities();
  public A addNewAdditionalCertificateAuthority(String name);
  public HiveConfigSpecFluent.AdditionalCertificateAuthoritiesNested<A> addNewAdditionalCertificateAuthority();
  public HiveConfigSpecFluent.AdditionalCertificateAuthoritiesNested<A> addNewAdditionalCertificateAuthorityLike(LocalObjectReference item);
  public HiveConfigSpecFluent.AdditionalCertificateAuthoritiesNested<A> setNewAdditionalCertificateAuthorityLike(Integer index,LocalObjectReference item);
  public HiveConfigSpecFluent.AdditionalCertificateAuthoritiesNested<A> editAdditionalCertificateAuthority(Integer index);
  public HiveConfigSpecFluent.AdditionalCertificateAuthoritiesNested<A> editFirstAdditionalCertificateAuthority();
  public HiveConfigSpecFluent.AdditionalCertificateAuthoritiesNested<A> editLastAdditionalCertificateAuthority();
  public HiveConfigSpecFluent.AdditionalCertificateAuthoritiesNested<A> editMatchingAdditionalCertificateAuthority(Predicate<LocalObjectReferenceBuilder> predicate);
  
  /**
   * This method has been deprecated, please use method buildBackup instead.
   * @return The buildable object.
   */
  @Deprecated
  public BackupConfig getBackup();
  public BackupConfig buildBackup();
  public A withBackup(BackupConfig backup);
  public Boolean hasBackup();
  public HiveConfigSpecFluent.BackupNested<A> withNewBackup();
  public HiveConfigSpecFluent.BackupNested<A> withNewBackupLike(BackupConfig item);
  public HiveConfigSpecFluent.BackupNested<A> editBackup();
  public HiveConfigSpecFluent.BackupNested<A> editOrNewBackup();
  public HiveConfigSpecFluent.BackupNested<A> editOrNewBackupLike(BackupConfig item);
  
  /**
   * This method has been deprecated, please use method buildExternalDNS instead.
   * @return The buildable object.
   */
  @Deprecated
  public ExternalDNSConfig getExternalDNS();
  public ExternalDNSConfig buildExternalDNS();
  public A withExternalDNS(ExternalDNSConfig externalDNS);
  public Boolean hasExternalDNS();
  public HiveConfigSpecFluent.ExternalDNSNested<A> withNewExternalDNS();
  public HiveConfigSpecFluent.ExternalDNSNested<A> withNewExternalDNSLike(ExternalDNSConfig item);
  public HiveConfigSpecFluent.ExternalDNSNested<A> editExternalDNS();
  public HiveConfigSpecFluent.ExternalDNSNested<A> editOrNewExternalDNS();
  public HiveConfigSpecFluent.ExternalDNSNested<A> editOrNewExternalDNSLike(ExternalDNSConfig item);
  
  /**
   * This method has been deprecated, please use method buildFailedProvisionConfig instead.
   * @return The buildable object.
   */
  @Deprecated
  public FailedProvisionConfig getFailedProvisionConfig();
  public FailedProvisionConfig buildFailedProvisionConfig();
  public A withFailedProvisionConfig(FailedProvisionConfig failedProvisionConfig);
  public Boolean hasFailedProvisionConfig();
  public A withNewFailedProvisionConfig(Boolean skipGatherLogs);
  public HiveConfigSpecFluent.FailedProvisionConfigNested<A> withNewFailedProvisionConfig();
  public HiveConfigSpecFluent.FailedProvisionConfigNested<A> withNewFailedProvisionConfigLike(FailedProvisionConfig item);
  public HiveConfigSpecFluent.FailedProvisionConfigNested<A> editFailedProvisionConfig();
  public HiveConfigSpecFluent.FailedProvisionConfigNested<A> editOrNewFailedProvisionConfig();
  public HiveConfigSpecFluent.FailedProvisionConfigNested<A> editOrNewFailedProvisionConfigLike(FailedProvisionConfig item);
  
  /**
   * This method has been deprecated, please use method buildGlobalPullSecret instead.
   * @return The buildable object.
   */
  @Deprecated
  public LocalObjectReference getGlobalPullSecret();
  public LocalObjectReference buildGlobalPullSecret();
  public A withGlobalPullSecret(LocalObjectReference globalPullSecret);
  public Boolean hasGlobalPullSecret();
  public A withNewGlobalPullSecret(String name);
  public HiveConfigSpecFluent.GlobalPullSecretNested<A> withNewGlobalPullSecret();
  public HiveConfigSpecFluent.GlobalPullSecretNested<A> withNewGlobalPullSecretLike(LocalObjectReference item);
  public HiveConfigSpecFluent.GlobalPullSecretNested<A> editGlobalPullSecret();
  public HiveConfigSpecFluent.GlobalPullSecretNested<A> editOrNewGlobalPullSecret();
  public HiveConfigSpecFluent.GlobalPullSecretNested<A> editOrNewGlobalPullSecretLike(LocalObjectReference item);
  public Boolean getMaintenanceMode();
  public A withMaintenanceMode(Boolean maintenanceMode);
  public Boolean hasMaintenanceMode();
  public A withMaintenanceMode();
  public interface AdditionalCertificateAuthoritiesNested<N> extends Nested<N>,LocalObjectReferenceFluent<HiveConfigSpecFluent.AdditionalCertificateAuthoritiesNested<N>>{
    public N and();
    public N endAdditionalCertificateAuthority();
    
  }
  public interface BackupNested<N> extends Nested<N>,BackupConfigFluent<HiveConfigSpecFluent.BackupNested<N>>{
    public N and();
    public N endBackup();
    
  }
  public interface ExternalDNSNested<N> extends Nested<N>,ExternalDNSConfigFluent<HiveConfigSpecFluent.ExternalDNSNested<N>>{
    public N and();
    public N endExternalDNS();
    
  }
  public interface FailedProvisionConfigNested<N> extends Nested<N>,FailedProvisionConfigFluent<HiveConfigSpecFluent.FailedProvisionConfigNested<N>>{
    public N and();
    public N endFailedProvisionConfig();
    
  }
  public interface GlobalPullSecretNested<N> extends Nested<N>,LocalObjectReferenceFluent<HiveConfigSpecFluent.GlobalPullSecretNested<N>>{
    public N and();
    public N endGlobalPullSecret();
    
  }
  
}

==> open-cluster-management-operator-model-6.7.1-sources.jar: io/fabric8/openclustermanagement/api/model/multiclusterhub/operator/v1/HiveConfigSpecFluent.java <==
package io.fabric8.openclustermanagement.api.model.multiclusterhub.operator.v1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import com.fasterxml.jackson.annotation.JsonProperty;
import com.fasterxml.jackson.annotation.JsonInclude;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import java.util.function.Predicate;
import java.lang.Deprecated;
import java.util.Iterator;
import java.util.List;
import java.lang.Boolean;
import io.fabric8.kubernetes.api.model.LocalObjectReferenceFluent;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.model.LocalObjectReferenceBuilder;
import io.fabric8.kubernetes.api.model.LocalObjectReference;
import java.util.Collection;

 /**
  * Generated
  */
public interface HiveConfigSpecFluent<A extends HiveConfigSpecFluent<A>> extends Fluent<A>{
  public A addToAdditionalCertificateAuthorities(int index,LocalObjectReference item);
  public A setToAdditionalCertificateAuthorities(int index,LocalObjectReference item);
  public A addToAdditionalCertificateAuthorities(io.fabric8.kubernetes.api.model.LocalObjectReference... items);
  public A addAllToAdditionalCertificateAuthorities(Collection<LocalObjectReference> items);
  public A removeFromAdditionalCertificateAuthorities(io.fabric8.kubernetes.api.model.LocalObjectReference... items);
  public A removeAllFromAdditionalCertificateAuthorities(Collection<LocalObjectReference> items);
  public A removeMatchingFromAdditionalCertificateAuthorities(Predicate<LocalObjectReferenceBuilder> predicate);
  
  /**
   * This method has been deprecated, please use method buildAdditionalCertificateAuthorities instead.
   * @return The buildable object.
   */
  @Deprecated
  public List<LocalObjectReference> getAdditionalCertificateAuthorities();
  public List<LocalObjectReference> buildAdditionalCertificateAuthorities();
  public LocalObjectReference buildAdditionalCertificateAuthority(int index);
  public LocalObjectReference buildFirstAdditionalCertificateAuthority();
  public LocalObjectReference buildLastAdditionalCertificateAuthority();
  public LocalObjectReference buildMatchingAdditionalCertificateAuthority(Predicate<LocalObjectReferenceBuilder> predicate);
  public Boolean hasMatchingAdditionalCertificateAuthority(Predicate<LocalObjectReferenceBuilder> predicate);
  public A withAdditionalCertificateAuthorities(List<LocalObjectReference> additionalCertificateAuthorities);
  public A withAdditionalCertificateAuthorities(io.fabric8.kubernetes.api.model.LocalObjectReference... additionalCertificateAuthorities);
  public Boolean hasAdditionalCertificateAuthorities();
  public A addNewAdditionalCertificateAuthority(String name);
  public HiveConfigSpecFluent.AdditionalCertificateAuthoritiesNested<A> addNewAdditionalCertificateAuthority();
  public HiveConfigSpecFluent.AdditionalCertificateAuthoritiesNested<A> addNewAdditionalCertificateAuthorityLike(LocalObjectReference item);
  public HiveConfigSpecFluent.AdditionalCertificateAuthoritiesNested<A> setNewAdditionalCertificateAuthorityLike(int index,LocalObjectReference item);
  public HiveConfigSpecFluent.AdditionalCertificateAuthoritiesNested<A> editAdditionalCertificateAuthority(int index);
  public HiveConfigSpecFluent.AdditionalCertificateAuthoritiesNested<A> editFirstAdditionalCertificateAuthority();
  public HiveConfigSpecFluent.AdditionalCertificateAuthoritiesNested<A> editLastAdditionalCertificateAuthority();
  public HiveConfigSpecFluent.AdditionalCertificateAuthoritiesNested<A> editMatchingAdditionalCertificateAuthority(Predicate<LocalObjectReferenceBuilder> predicate);
  
  /**
   * This method has been deprecated, please use method buildBackup instead.
   * @return The buildable object.
   */
  @Deprecated
  public BackupConfig getBackup();
  public BackupConfig buildBackup();
  public A withBackup(BackupConfig backup);
  public Boolean hasBackup();
  public HiveConfigSpecFluent.BackupNested<A> withNewBackup();
  public HiveConfigSpecFluent.BackupNested<A> withNewBackupLike(BackupConfig item);
  public HiveConfigSpecFluent.BackupNested<A> editBackup();
  public HiveConfigSpecFluent.BackupNested<A> editOrNewBackup();
  public HiveConfigSpecFluent.BackupNested<A> editOrNewBackupLike(BackupConfig item);
  
  /**
   * This method has been deprecated, please use method buildExternalDNS instead.
   * @return The buildable object.
   */
  @Deprecated
  public ExternalDNSConfig getExternalDNS();
  public ExternalDNSConfig buildExternalDNS();
  public A withExternalDNS(ExternalDNSConfig externalDNS);
  public Boolean hasExternalDNS();
  public HiveConfigSpecFluent.ExternalDNSNested<A> withNewExternalDNS();
  public HiveConfigSpecFluent.ExternalDNSNested<A> withNewExternalDNSLike(ExternalDNSConfig item);
  public HiveConfigSpecFluent.ExternalDNSNested<A> editExternalDNS();
  public HiveConfigSpecFluent.ExternalDNSNested<A> editOrNewExternalDNS();
  public HiveConfigSpecFluent.ExternalDNSNested<A> editOrNewExternalDNSLike(ExternalDNSConfig item);
  
  /**
   * This method has been deprecated, please use method buildFailedProvisionConfig instead.
   * @return The buildable object.
   */
  @Deprecated
  public FailedProvisionConfig getFailedProvisionConfig();
  public FailedProvisionConfig buildFailedProvisionConfig();
  public A withFailedProvisionConfig(FailedProvisionConfig failedProvisionConfig);
  public Boolean hasFailedProvisionConfig();
  public A withNewFailedProvisionConfig(Boolean skipGatherLogs);
  public HiveConfigSpecFluent.FailedProvisionConfigNested<A> withNewFailedProvisionConfig();
  public HiveConfigSpecFluent.FailedProvisionConfigNested<A> withNewFailedProvisionConfigLike(FailedProvisionConfig item);
  public HiveConfigSpecFluent.FailedProvisionConfigNested<A> editFailedProvisionConfig();
  public HiveConfigSpecFluent.FailedProvisionConfigNested<A> editOrNewFailedProvisionConfig();
  public HiveConfigSpecFluent.FailedProvisionConfigNested<A> editOrNewFailedProvisionConfigLike(FailedProvisionConfig item);
  
  /**
   * This method has been deprecated, please use method buildGlobalPullSecret instead.
   * @return The buildable object.
   */
  @Deprecated
  public LocalObjectReference getGlobalPullSecret();
  public LocalObjectReference buildGlobalPullSecret();
  public A withGlobalPullSecret(LocalObjectReference globalPullSecret);
  public Boolean hasGlobalPullSecret();
  public A withNewGlobalPullSecret(String name);
  public HiveConfigSpecFluent.GlobalPullSecretNested<A> withNewGlobalPullSecret();
  public HiveConfigSpecFluent.GlobalPullSecretNested<A> withNewGlobalPullSecretLike(LocalObjectReference item);
  public HiveConfigSpecFluent.GlobalPullSecretNested<A> editGlobalPullSecret();
  public HiveConfigSpecFluent.GlobalPullSecretNested<A> editOrNewGlobalPullSecret();
  public HiveConfigSpecFluent.GlobalPullSecretNested<A> editOrNewGlobalPullSecretLike(LocalObjectReference item);
  public Boolean getMaintenanceMode();
  public A withMaintenanceMode(Boolean maintenanceMode);
  public Boolean hasMaintenanceMode();
  public A withMaintenanceMode();
  public interface AdditionalCertificateAuthoritiesNested<N> extends Nested<N>,LocalObjectReferenceFluent<HiveConfigSpecFluent.AdditionalCertificateAuthoritiesNested<N>>{
    public N and();
    public N endAdditionalCertificateAuthority();
    
  }
  public interface BackupNested<N> extends Nested<N>,BackupConfigFluent<HiveConfigSpecFluent.BackupNested<N>>{
    public N and();
    public N endBackup();
    
  }
  public interface ExternalDNSNested<N> extends Nested<N>,ExternalDNSConfigFluent<HiveConfigSpecFluent.ExternalDNSNested<N>>{
    public N and();
    public N endExternalDNS();
    
  }
  public interface FailedProvisionConfigNested<N> extends Nested<N>,FailedProvisionConfigFluent<HiveConfigSpecFluent.FailedProvisionConfigNested<N>>{
    public N and();
    public N endFailedProvisionConfig();
    
  }
  public interface GlobalPullSecretNested<N> extends Nested<N>,LocalObjectReferenceFluent<HiveConfigSpecFluent.GlobalPullSecretNested<N>>{
    public N and();
    public N endGlobalPullSecret();
    
  }
  
}
